@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2010, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2010, Sebastian Bergmann <sebastian@phpunit.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,40 +34,17 @@
  * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- * @category   Testing
  * @package    PHPUnit
- * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @author     Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.0.0
  */
 
-require_once 'PHPUnit/Util/Filter.php';
+require_once 'PHP/CodeCoverage/Filter.php';
+PHP_CodeCoverage_Filter::getInstance()->addFileToBlacklist(__FILE__, 'PHPUNIT');
 
-PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
-
-require 'PHPUnit/Framework/Exception.php';
-require 'PHPUnit/Framework/SelfDescribing.php';
-require 'PHPUnit/Framework/AssertionFailedError.php';
-require 'PHPUnit/Framework/Assert.php';
-require 'PHPUnit/Framework/Error.php';
-require 'PHPUnit/Framework/Error/Notice.php';
-require 'PHPUnit/Framework/Error/Warning.php';
-require 'PHPUnit/Framework/IncompleteTest.php';
-require 'PHPUnit/Framework/SkippedTest.php';
-require 'PHPUnit/Framework/Test.php';
-require 'PHPUnit/Framework/TestFailure.php';
-require 'PHPUnit/Framework/TestListener.php';
-require 'PHPUnit/Framework/TestResult.php';
-require 'PHPUnit/Framework/ExpectationFailedException.php';
-require 'PHPUnit/Framework/IncompleteTestError.php';
-require 'PHPUnit/Framework/SkippedTestError.php';
-require 'PHPUnit/Framework/SkippedTestSuiteError.php';
-require 'PHPUnit/Framework/TestCase.php';
-require 'PHPUnit/Framework/TestSuite.php';
-require 'PHPUnit/Framework/TestSuite/DataProvider.php';
-require 'PHPUnit/Framework/Warning.php';
-require 'PHPUnit/Framework/Constraint.php';
-require 'PHPUnit/Framework/ComparisonFailure.php';
-?>
\ No newline at end of file
+trigger_error(
+  'Please no longer include "PHPUnit/Framework.php".', E_USER_NOTICE
+);
