@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2010, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2010, Sebastian Bergmann <sebastian@phpunit.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,35 +34,27 @@
  * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- * @category   Testing
  * @package    PHPUnit
- * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @subpackage Framework
+ * @author     Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.0.0
  */
 
-require_once 'PHPUnit/Framework.php';
-
-require_once 'PHPUnit/Util/CodeCoverage.php';
-require_once 'PHPUnit/Util/ErrorHandler.php';
-require_once 'PHPUnit/Util/InvalidArgumentHelper.php';
-require_once 'PHPUnit/Util/Printer.php';
-require_once 'PHPUnit/Util/Test.php';
-require_once 'PHPUnit/Util/Timer.php';
-
-PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
+require_once 'PHP/CodeCoverage.php';
+require_once 'PHP/Timer.php';
 
 /**
  * A TestResult collects the results of executing a test case.
  *
- * @category   Testing
  * @package    PHPUnit
- * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @subpackage Framework
+ * @author     Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.4.14
+ * @version    Release: 3.5.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.0.0
  */
@@ -79,87 +71,124 @@ class PHPUnit_Framework_TestResult implements Countable
     protected static $useXdebug = NULL;
 
     /**
-     * @var    array
+     * @var array
      */
     protected $passed = array();
 
     /**
-     * @var    array
+     * @var array
      */
     protected $errors = array();
 
     /**
-     * @var    array
+     * @var array
      */
     protected $failures = array();
 
     /**
-     * @var    array
+     * @var array
      */
     protected $notImplemented = array();
 
     /**
-     * @var    array
+     * @var array
      */
     protected $skipped = array();
 
     /**
-     * @var    array
+     * @var array
      */
     protected $listeners = array();
 
     /**
-     * @var    integer
+     * @var integer
      */
     protected $runTests = 0;
 
     /**
-     * @var    float
+     * @var float
      */
     protected $time = 0;
 
     /**
-     * @var    PHPUnit_Framework_TestSuite
+     * @var PHPUnit_Framework_TestSuite
      */
     protected $topTestSuite = NULL;
 
     /**
-     * Code Coverage information provided by Xdebug.
+     * Code Coverage information.
      *
-     * @var    array
+     * @var array
      */
-    protected $codeCoverageInformation = array();
+    protected $codeCoverage;
 
     /**
-     * @var    boolean
+     * @var boolean
      */
     protected $collectCodeCoverageInformation = FALSE;
 
     /**
-     * @var    boolean
+     * @var boolean
      */
     protected $collectRawCodeCoverageInformation = FALSE;
 
     /**
-     * @var    boolean
+     * @var array
+     */
+    protected $rawCodeCoverageInformation = array();
+
+    /**
+     * @var boolean
      */
     protected $convertErrorsToExceptions = TRUE;
 
     /**
-     * @var    boolean
+     * @var boolean
      */
     protected $stop = FALSE;
 
     /**
-     * @var    boolean
+     * @var boolean
+     */
+    protected $stopOnError = FALSE;
+
+    /**
+     * @var boolean
      */
     protected $stopOnFailure = FALSE;
 
     /**
-     * @var    boolean
+     * @var boolean
+     */
+    protected $strictMode = FALSE;
+
+    /**
+     * @var boolean
+     */
+    protected $stopOnIncomplete = FALSE;
+
+    /**
+     * @var boolean
+     */
+    protected $stopOnSkipped = FALSE;
+
+    /**
+     * @var boolean
      */
     protected $lastTestFailed = FALSE;
 
+    /**
+     * @param PHP_CodeCoverage $codeCoverage
+     */
+    public function __construct(PHP_CodeCoverage $codeCoverage = NULL)
+    {
+        if ($codeCoverage === NULL) {
+            $codeCoverage = PHP_CodeCoverage::getInstance();
+        }
+
+        $this->codeCoverage = $codeCoverage;
+    }
+
     /**
      * Registers a TestListener.
      *
@@ -213,18 +242,26 @@ class PHPUnit_Framework_TestResult implements Countable
             );
 
             $notifyMethod = 'addIncompleteTest';
+
+            if ($this->stopOnIncomplete) {
+                $this->stop();
+            }
         }
 
         else if ($e instanceof PHPUnit_Framework_SkippedTest) {
             $this->skipped[] = new PHPUnit_Framework_TestFailure($test, $e);
             $notifyMethod    = 'addSkippedTest';
+
+            if ($this->stopOnSkipped) {
+                $this->stop();
+            }
         }
 
         else {
             $this->errors[] = new PHPUnit_Framework_TestFailure($test, $e);
             $notifyMethod   = 'addError';
 
-            if ($this->stopOnFailure) {
+            if ($this->stopOnError || $this->stopOnFailure) {
                 $this->stop();
             }
         }
@@ -253,11 +290,19 @@ class PHPUnit_Framework_TestResult implements Countable
             );
 
             $notifyMethod = 'addIncompleteTest';
+
+            if ($this->stopOnIncomplete) {
+                $this->stop();
+            }
         }
 
         else if ($e instanceof PHPUnit_Framework_SkippedTest) {
             $this->skipped[] = new PHPUnit_Framework_TestFailure($test, $e);
             $notifyMethod    = 'addSkippedTest';
+
+            if ($this->stopOnSkipped) {
+                $this->stop();
+            }
         }
 
         else {
@@ -336,7 +381,7 @@ class PHPUnit_Framework_TestResult implements Countable
 
         if (!$this->lastTestFailed && $test instanceof PHPUnit_Framework_TestCase) {
             $this->passed[get_class($test) . '::' . $test->getName()] = $test->getResult();
-            $this->time += $time;
+            $this->time                                              += $time;
         }
     }
 
@@ -512,75 +557,6 @@ class PHPUnit_Framework_TestResult implements Countable
         return $this->collectCodeCoverageInformation;
     }
 
-    /**
-     * Appends code coverage information to the test
-     *
-     * @param PHPUnit_Framework_Test $test
-     * @param array                  $data
-     * @since Method available since Release 3.2.0
-     */
-    public function appendCodeCoverageInformation(PHPUnit_Framework_Test $test, $data)
-    {
-        if ($this->collectRawCodeCoverageInformation) {
-            $this->codeCoverageInformation[] = array(
-              'test' => $test, 'data' => $data
-            );
-        } else {
-            $deadCode       = array();
-            $executableCode = array();
-
-            foreach (array_keys($data) as $file) {
-                if (PHPUnit_Util_Filter::isFiltered($file, FALSE)) {
-                    unset($data[$file]);
-                }
-            }
-
-            $newFilesToCollect = array_diff_key($data, PHPUnit_Util_Filter::getCoveredFiles());
-
-            if (count($newFilesToCollect) > 0) {
-                $deadCode = PHPUnit_Util_CodeCoverage::getDeadLines(
-                  $newFilesToCollect
-                );
-
-                $executableCode = PHPUnit_Util_CodeCoverage::getExecutableLines(
-                  $newFilesToCollect
-                );
-
-                foreach (array_keys($newFilesToCollect) as $file) {
-                    PHPUnit_Util_Filter::addCoveredFile($file);
-                }
-
-                unset($newFilesToCollect);
-            }
-
-            if ($test instanceof PHPUnit_Framework_TestCase) {
-                $linesToBeCovered = PHPUnit_Util_Test::getLinesToBeCovered(
-                  get_class($test), $test->getName()
-                );
-
-                if (!empty($linesToBeCovered)) {
-                    $data = array_intersect_key($data, $linesToBeCovered);
-
-                    foreach (array_keys($data) as $file) {
-                        $data[$file] = array_intersect_key(
-                          $data[$file], array_flip($linesToBeCovered[$file])
-                        );
-                    }
-                }
-            }
-
-            $executed = PHPUnit_Util_CodeCoverage::getExecutedLines($data);
-            unset($data);
-
-            $this->codeCoverageInformation[] = array(
-              'test'       => $test,
-              'files'      => $executed,
-              'dead'       => $deadCode,
-              'executable' => $executableCode,
-            );
-        }
-    }
-
     /**
      * Returns the raw Code Coverage information.
      *
@@ -589,53 +565,17 @@ class PHPUnit_Framework_TestResult implements Countable
      */
     public function getRawCodeCoverageInformation()
     {
-        return $this->codeCoverageInformation;
+        return $this->rawCodeCoverageInformation;
     }
 
     /**
-     * Returns Code Coverage data per test case.
+     * Returns the strict mode configuration option
      *
-     * Format of the result array:
-     *
-     * <code>
-     * array(
-     *   array(
-     *     'test'  => PHPUnit_Framework_Test
-     *     'files' => array(
-     *       "/tested/code.php" => array(
-     *         linenumber => flag
-     *       )
-     *     )
-     *   )
-     * )
-     * </code>
-     *
-     * flag < 0: Line is executable but was not executed.
-     * flag > 0: Line was executed.
-     *
-     * @param  boolean $filterTests
-     * @return array
+     * @return boolean
      */
-    public function getCodeCoverageInformation($filterTests = TRUE)
+    public function isStrict()
     {
-        return PHPUnit_Util_Filter::getFilteredCodeCoverage(
-          $this->codeCoverageInformation, $filterTests
-        );
-    }
-
-    /**
-     * Returns unfiltered Code Coverage data per test case.
-     * Returns data in the same form as getCodeCoverageInformation().
-     *
-     * @return array
-     */
-    public function getUncoveredWhitelistFiles()
-    {
-        list(, $missing) = PHPUnit_Util_Filter::getFileCodeCoverageDisposition(
-          $this->codeCoverageInformation
-        );
-
-        return $missing;
+        return $this->strictMode;
     }
 
     /**
@@ -647,8 +587,10 @@ class PHPUnit_Framework_TestResult implements Countable
     {
         PHPUnit_Framework_Assert::resetCount();
 
-        $error   = FALSE;
-        $failure = FALSE;
+        $error      = FALSE;
+        $failure    = FALSE;
+        $incomplete = FALSE;
+        $skipped    = FALSE;
 
         $this->startTest($test);
 
@@ -674,13 +616,14 @@ class PHPUnit_Framework_TestResult implements Countable
 
         $useXdebug = self::$useXdebug &&
                      $this->collectCodeCoverageInformation &&
-                     !$test instanceof PHPUnit_Extensions_SeleniumTestCase;
+                     !$test instanceof PHPUnit_Extensions_SeleniumTestCase &&
+                     !$test instanceof PHPUnit_Framework_Warning;
 
         if ($useXdebug) {
-            xdebug_start_code_coverage(XDEBUG_CC_UNUSED | XDEBUG_CC_DEAD_CODE);
+            $this->codeCoverage->start($test);
         }
 
-        PHPUnit_Util_Timer::start();
+        PHP_Timer::start();
 
         try {
             $test->runBare();
@@ -688,23 +631,40 @@ class PHPUnit_Framework_TestResult implements Countable
 
         catch (PHPUnit_Framework_AssertionFailedError $e) {
             $failure = TRUE;
+
+            if ($e instanceof PHPUnit_Framework_IncompleteTestError) {
+                $incomplete = TRUE;
+            }
+
+            else if ($e instanceof PHPUnit_Framework_SkippedTestError) {
+                $skipped = TRUE;
+            }
         }
 
         catch (Exception $e) {
             $error = TRUE;
         }
 
-        $time = PHPUnit_Util_Timer::stop();
+        $time = PHP_Timer::stop();
 
         if ($useXdebug) {
-            $codeCoverage = xdebug_get_code_coverage();
-            xdebug_stop_code_coverage();
+            $data = $this->codeCoverage->stop(FALSE);
 
-            if (!$test instanceof PHPUnit_Framework_Warning) {
-                $this->appendCodeCoverageInformation(
-                  $test, $codeCoverage
-                );
+            if (!$this->strictMode || (!$incomplete && !$skipped)) {
+                if ($this->collectRawCodeCoverageInformation) {
+                    $this->rawCodeCoverageInformation[] = $data;
+                } else {
+                    $filterGroups = array('DEFAULT', 'TESTS');
+
+                    if (!defined('PHPUNIT_TESTSUITE')) {
+                        $filterGroups[] = 'PHPUNIT';
+                    }
+
+                    $this->codeCoverage->append($data, $test, $filterGroups);
+                }
             }
+
+            unset($data);
         }
 
         if ($errorHandlerSet === TRUE) {
@@ -721,6 +681,16 @@ class PHPUnit_Framework_TestResult implements Countable
             $this->addFailure($test, $e, $time);
         }
 
+        else if ($this->strictMode && $test->getNumAssertions() == 0) {
+            $this->addFailure(
+              $test,
+              new PHPUnit_Framework_IncompleteTestError(
+                'This test did not perform any assertions'
+              ),
+              $time
+            );
+        }
+
         $this->endTest($test, $time);
     }
 
@@ -753,6 +723,17 @@ class PHPUnit_Framework_TestResult implements Countable
         $this->stop = TRUE;
     }
 
+    /**
+     * Returns the PHP_CodeCoverage object.
+     *
+     * @return PHP_CodeCoverage
+     * @since  Method available since Release 3.5.0
+     */
+    public function getCodeCoverage()
+    {
+        return $this->codeCoverage;
+    }
+
     /**
      * Enables or disables the error-to-exception conversion.
      *
@@ -781,7 +762,23 @@ class PHPUnit_Framework_TestResult implements Countable
     }
 
     /**
-     * Enables or disables the stopping when a failure or error occurs.
+     * Enables or disables the stopping when an error occurs.
+     *
+     * @param  boolean $flag
+     * @throws InvalidArgumentException
+     * @since  Method available since Release 3.5.0
+     */
+    public function stopOnError($flag)
+    {
+        if (is_bool($flag)) {
+            $this->stopOnError = $flag;
+        } else {
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'boolean');
+        }
+    }
+
+    /**
+     * Enables or disables the stopping when a failure occurs.
      *
      * @param  boolean $flag
      * @throws InvalidArgumentException
@@ -796,6 +793,58 @@ class PHPUnit_Framework_TestResult implements Countable
         }
     }
 
+    /**
+     * Enables or disables the strict mode.
+     *
+     * When active
+     *   * Tests that do not assert anything will be marked as incomplete.
+     *   * Tests that are incomplete or skipped yield no code coverage.
+     *
+     * @param  boolean $flag
+     * @throws InvalidArgumentException
+     * @since  Method available since Release 3.5.2
+     */
+    public function strictMode($flag)
+    {
+        if (is_bool($flag)) {
+            $this->strictMode = $flag;
+        } else {
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'boolean');
+        }
+    }
+
+    /**
+     * Enables or disables the stopping for incomplete tests.
+     *
+     * @param  boolean $flag
+     * @throws InvalidArgumentException
+     * @since  Method available since Release 3.5.0
+     */
+    public function stopOnIncomplete($flag)
+    {
+        if (is_bool($flag)) {
+            $this->stopOnIncomplete = $flag;
+        } else {
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'boolean');
+        }
+    }
+
+    /**
+     * Enables or disables the stopping for skipped tests.
+     *
+     * @param  boolean $flag
+     * @throws InvalidArgumentException
+     * @since  Method available since Release 3.1.0
+     */
+    public function stopOnSkipped($flag)
+    {
+        if (is_bool($flag)) {
+            $this->stopOnSkipped = $flag;
+        } else {
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'boolean');
+        }
+    }
+
     /**
      * Returns the time spent running the tests.
      *
@@ -816,4 +865,3 @@ class PHPUnit_Framework_TestResult implements Countable
         return empty($this->errors) && empty($this->failures);
     }
 }
-?>
\ No newline at end of file
