@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2010, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2010, Sebastian Bergmann <sebastian@phpunit.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,40 +34,61 @@
  * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- * @category   Testing
  * @package    PHPUnit
- * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @subpackage Framework
+ * @author     Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.0.0
  */
 
-require_once 'PHPUnit/Framework.php';
-
-PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
-
 /**
  * A warning.
  *
- * @category   Testing
  * @package    PHPUnit
- * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @subpackage Framework
+ * @author     Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.4.14
+ * @version    Release: 3.5.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.0.0
  */
 class PHPUnit_Framework_Warning extends PHPUnit_Framework_TestCase
 {
     /**
-     * @var    string
+     * @var string
      */
     protected $message = '';
 
     /**
-     * @param  string  $message
+     * @var boolean
+     */
+    protected $backupGlobals = FALSE;
+
+    /**
+     * @var boolean
+     */
+    protected $backupStaticAttributes = FALSE;
+
+    /**
+     * @var boolean
+     */
+    protected $runTestInSeparateProcess = FALSE;
+
+    /**
+     * @var boolean
+     */
+    protected $useErrorHandler = FALSE;
+
+    /**
+     * @var boolean
+     */
+    protected $useOutputBuffering = FALSE;
+
+    /**
+     * @param string $message
      */
     public function __construct($message = '')
     {
@@ -103,4 +124,3 @@ class PHPUnit_Framework_Warning extends PHPUnit_Framework_TestCase
         return 'Warning';
     }
 }
-?>
\ No newline at end of file
