@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2010, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2010, Sebastian Bergmann <sebastian@phpunit.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,20 +34,16 @@
  * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- * @category   Testing
  * @package    PHPUnit
- * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @subpackage Runner
+ * @author     Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.1.0
  */
 
-require_once 'PHPUnit/Util/Filter.php';
-require_once 'PHPUnit/Runner/TestCollector.php';
-require_once 'PHPUnit/Util/FilterIterator.php';
-
-PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
+require_once 'File/Iterator/Factory.php';
 
 /**
  * A test collector that collects tests from one or more directories
@@ -62,12 +58,12 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * $suite->addTestFiles($testCollector->collectTests());
  * </code>
  *
- * @category   Testing
  * @package    PHPUnit
- * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @subpackage Runner
+ * @author     Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.4.14
+ * @version    Release: 3.5.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.1.0
  */
@@ -111,31 +107,20 @@ class PHPUnit_Runner_IncludePathTestCollector implements PHPUnit_Runner_TestColl
     }
 
     /**
-     * @return array
+     * @return File_Iterator
      */
     public function collectTests()
     {
-        $pathIterator = new AppendIterator;
-        $result       = array();
-
-        foreach ($this->paths as $path) {
-            $pathIterator->append(
-              new RecursiveIteratorIterator(
-                new RecursiveDirectoryIterator($path)
-              )
-            );
-        }
-
-        $filterIterator = new PHPUnit_Util_FilterIterator(
-          $pathIterator, $this->suffixes, $this->prefixes
+        $iterator = File_Iterator_Factory::getFileIterator(
+          $this->paths, $this->suffixes, $this->prefixes
         );
 
         if ($this->filterIterator !== NULL) {
-            $class          = new ReflectionClass($this->filterIterator);
-            $filterIterator = $class->newInstance($filterIterator);
+            $class    = new ReflectionClass($this->filterIterator);
+            $iterator = $class->newInstance($iterator);
         }
 
-        return $filterIterator;
+        return $iterator;
     }
 
     /**
@@ -157,4 +142,3 @@ class PHPUnit_Runner_IncludePathTestCollector implements PHPUnit_Runner_TestColl
         }
     }
 }
-?>
\ No newline at end of file
