@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2010, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2010, Sebastian Bergmann <sebastian@phpunit.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,34 +34,25 @@
  * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- * @category   Testing
  * @package    PHPUnit
- * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @subpackage TextUI
+ * @author     Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.0.0
  */
 
-require_once 'PHPUnit/TextUI/TestRunner.php';
-require_once 'PHPUnit/Util/Configuration.php';
-require_once 'PHPUnit/Util/Fileloader.php';
-require_once 'PHPUnit/Util/Filesystem.php';
-require_once 'PHPUnit/Util/Filter.php';
-require_once 'PHPUnit/Util/Getopt.php';
-
-PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
-
 /**
  * A TestRunner for the Command Line Interface (CLI)
  * PHP SAPI Module.
  *
- * @category   Testing
  * @package    PHPUnit
- * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @subpackage TextUI
+ * @author     Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.4.14
+ * @version    Release: 3.5.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.0.0
  */
@@ -86,14 +77,11 @@ class PHPUnit_TextUI_Command
      * @var array
      */
     protected $longOptions = array(
-      'ansi' => NULL,
       'colors' => NULL,
       'bootstrap=' => NULL,
       'configuration=' => NULL,
       'coverage-html=' => NULL,
       'coverage-clover=' => NULL,
-      'coverage-source=' => NULL,
-      'coverage-xml=' => NULL,
       'debug' => NULL,
       'exclude-group=' => NULL,
       'filter=' => NULL,
@@ -102,30 +90,25 @@ class PHPUnit_TextUI_Command
       'include-path=' => NULL,
       'list-groups' => NULL,
       'loader=' => NULL,
-      'log-graphviz=' => NULL,
+      'log-dbus' => NULL,
       'log-json=' => NULL,
       'log-junit=' => NULL,
-      'log-metrics=' => NULL,
-      'log-pmd=' => NULL,
       'log-tap=' => NULL,
-      'log-xml=' => NULL,
       'process-isolation' => NULL,
       'repeat=' => NULL,
-      'report=' => NULL,
-      'skeleton' => NULL,
       'skeleton-class' => NULL,
       'skeleton-test' => NULL,
       'stderr' => NULL,
+      'stop-on-error' => NULL,
       'stop-on-failure' => NULL,
+      'stop-on-incomplete' => NULL,
+      'stop-on-skipped' => NULL,
       'story' => NULL,
       'story-html=' => NULL,
       'story-text=' => NULL,
+      'strict' => NULL,
       'syntax-check' => NULL,
       'tap' => NULL,
-      'test-db-dsn=' => NULL,
-      'test-db-log-rev=' => NULL,
-      'test-db-log-prefix=' => NULL,
-      'test-db-log-info=' => NULL,
       'testdox' => NULL,
       'testdox-html=' => NULL,
       'testdox-text=' => NULL,
@@ -167,17 +150,9 @@ class PHPUnit_TextUI_Command
             );
         }
 
-        if ($suite->testAt(0) instanceof PHPUnit_Framework_Warning &&
-            strpos($suite->testAt(0)->getMessage(), 'No tests found in class') !== FALSE) {
-            $message   = $suite->testAt(0)->getMessage();
-            $start     = strpos($message, '"') + 1;
-            $end       = strpos($message, '"', $start);
-            $className = substr($message, $start, $end - $start);
-
-            require_once 'PHPUnit/Util/Skeleton/Test.php';
-
+        if (count($suite) == 0) {
             $skeleton = new PHPUnit_Util_Skeleton_Test(
-              $className,
+              $suite->getName(),
               $this->arguments['testFile']
             );
 
@@ -262,7 +237,7 @@ class PHPUnit_TextUI_Command
         try {
             $this->options = PHPUnit_Util_Getopt::getopt(
               $argv,
-              'd:',
+              'd:c:',
               array_keys($this->longOptions)
             );
         }
@@ -276,14 +251,6 @@ class PHPUnit_TextUI_Command
 
         foreach ($this->options[0] as $option) {
             switch ($option[0]) {
-                case '--ansi': {
-                    $this->showMessage(
-                      'The --ansi option is deprecated, please use --colors ' .
-                      'instead.',
-                      FALSE
-                    );
-                }
-
                 case '--colors': {
                     $this->arguments['colors'] = TRUE;
                 }
@@ -294,19 +261,12 @@ class PHPUnit_TextUI_Command
                 }
                 break;
 
+                case 'c':
                 case '--configuration': {
                     $this->arguments['configuration'] = $option[1];
                 }
                 break;
 
-                case '--coverage-xml': {
-                    $this->showMessage(
-                      'The --coverage-xml option is deprecated, please use ' .
-                      '--coverage-clover instead.',
-                      FALSE
-                    );
-                }
-
                 case '--coverage-clover': {
                     if (extension_loaded('tokenizer') &&
                         extension_loaded('xdebug')) {
@@ -325,32 +285,6 @@ class PHPUnit_TextUI_Command
                 }
                 break;
 
-                case '--coverage-source': {
-                    if (extension_loaded('tokenizer') &&
-                        extension_loaded('xdebug')) {
-                        $this->arguments['coverageSource'] = $option[1];
-                    } else {
-                        if (!extension_loaded('tokenizer')) {
-                            $this->showMessage(
-                              'The tokenizer extension is not loaded.'
-                            );
-                        } else {
-                            $this->showMessage(
-                              'The Xdebug extension is not loaded.'
-                            );
-                        }
-                    }
-                }
-                break;
-
-                case '--report': {
-                    $this->showMessage(
-                      'The --report option is deprecated, please use ' .
-                      '--coverage-html instead.',
-                      FALSE
-                    );
-                }
-
                 case '--coverage-html': {
                     if (extension_loaded('tokenizer') &&
                         extension_loaded('xdebug')) {
@@ -425,94 +359,26 @@ class PHPUnit_TextUI_Command
                 }
                 break;
 
+                case '--log-dbus': {
+                    $this->arguments['logDbus'] = TRUE;
+                }
+                break;
+
                 case '--log-json': {
                     $this->arguments['jsonLogfile'] = $option[1];
                 }
                 break;
 
-                case '--log-xml': {
-                    $this->showMessage(
-                      'The --log-xml option is deprecated, please use ' .
-                      '--log-junit instead.',
-                      FALSE
-                    );
-                }
-
                 case '--log-junit': {
                     $this->arguments['junitLogfile'] = $option[1];
                 }
                 break;
 
-                case '--log-graphviz': {
-                    $this->showMessage(
-                      'The --log-graphviz functionality is deprecated and ' .
-                      'will be removed in the future.',
-                      FALSE
-                    );
-
-                    if (PHPUnit_Util_Filesystem::fileExistsInIncludePath('Image/GraphViz.php')) {
-                        $this->arguments['graphvizLogfile'] = $option[1];
-                    } else {
-                        $this->showMessage(
-                          'The Image_GraphViz package is not installed.'
-                        );
-                    }
-                }
-                break;
-
                 case '--log-tap': {
                     $this->arguments['tapLogfile'] = $option[1];
                 }
                 break;
 
-                case '--log-pmd': {
-                    $this->showMessage(
-                      'The --log-pmd functionality is deprecated and will be ' .
-                      'removed in the future.',
-                      FALSE
-                    );
-
-                    if (extension_loaded('tokenizer') &&
-                        extension_loaded('xdebug')) {
-                        $this->arguments['pmdXML'] = $option[1];
-                    } else {
-                        if (!extension_loaded('tokenizer')) {
-                            $this->showMessage(
-                              'The tokenizer extension is not loaded.'
-                            );
-                        } else {
-                            $this->showMessage(
-                              'The Xdebug extension is not loaded.'
-                            );
-                        }
-                    }
-                }
-                break;
-
-                case '--log-metrics': {
-                    $this->showMessage(
-                      'The --log-metrics functionality is deprecated and ' .
-                      'will be removed in the future.',
-                      FALSE
-                    );
-
-                    if (extension_loaded('tokenizer') &&
-                        extension_loaded('xdebug')) {
-                        $this->arguments['metricsXML'] = $option[1];
-                    } else {
-                        if (!extension_loaded('tokenizer')) {
-                            $this->showMessage(
-                              'The tokenizer extension is not loaded.'
-                            );
-                        } else {
-                            $this->showMessage(
-                              'The Xdebug extension is not loaded.'
-                            );
-                        }
-                    }
-                }
-                break;
-
                 case '--process-isolation': {
                     $this->arguments['processIsolation'] = TRUE;
                     $this->arguments['syntaxCheck']      = FALSE;
@@ -532,61 +398,26 @@ class PHPUnit_TextUI_Command
                 }
                 break;
 
+                case '--stop-on-error': {
+                    $this->arguments['stopOnError'] = TRUE;
+                }
+                break;
+
                 case '--stop-on-failure': {
                     $this->arguments['stopOnFailure'] = TRUE;
                 }
                 break;
 
-                case '--test-db-dsn': {
-                    $this->showMessage(
-                      'The test database functionality is deprecated and ' .
-                      'will be removed in the future.',
-                      FALSE
-                    );
-
-                    if (extension_loaded('pdo')) {
-                        $this->arguments['testDatabaseDSN'] = $option[1];
-                    } else {
-                        $this->showMessage('The PDO extension is not loaded.');
-                    }
+                case '--stop-on-incomplete': {
+                    $this->arguments['stopOnIncomplete'] = TRUE;
                 }
                 break;
 
-                case '--test-db-log-rev': {
-                    if (extension_loaded('pdo')) {
-                        $this->arguments['testDatabaseLogRevision'] = $option[1];
-                    } else {
-                        $this->showMessage('The PDO extension is not loaded.');
-                    }
+                case '--stop-on-skipped': {
+                    $this->arguments['stopOnSkipped'] = TRUE;
                 }
                 break;
 
-                case '--test-db-prefix': {
-                    if (extension_loaded('pdo')) {
-                        $this->arguments['testDatabasePrefix'] = $option[1];
-                    } else {
-                        $this->showMessage('The PDO extension is not loaded.');
-                    }
-                }
-                break;
-
-                case '--test-db-log-info': {
-                    if (extension_loaded('pdo')) {
-                        $this->arguments['testDatabaseLogInfo'] = $option[1];
-                    } else {
-                        $this->showMessage('The PDO extension is not loaded.');
-                    }
-                }
-                break;
-
-                case '--skeleton': {
-                    $this->showMessage(
-                      'The --skeleton option is deprecated, please use ' .
-                      '--skeleton-test instead.',
-                      FALSE
-                    );
-                }
-
                 case '--skeleton-test': {
                     $skeletonTest  = TRUE;
                     $skeletonClass = FALSE;
@@ -600,25 +431,39 @@ class PHPUnit_TextUI_Command
                 break;
 
                 case '--tap': {
-                    require_once 'PHPUnit/Util/Log/TAP.php';
-
                     $this->arguments['printer'] = new PHPUnit_Util_Log_TAP;
                 }
                 break;
 
                 case '--story': {
-                    require_once 'PHPUnit/Extensions/Story/ResultPrinter/Text.php';
+                    $this->showMessage(
+                      'The --story functionality is deprecated and ' .
+                      'will be removed in the future.',
+                      FALSE
+                    );
 
                     $this->arguments['printer'] = new PHPUnit_Extensions_Story_ResultPrinter_Text;
                 }
                 break;
 
                 case '--story-html': {
+                    $this->showMessage(
+                      'The --story-html functionality is deprecated and ' .
+                      'will be removed in the future.',
+                      FALSE
+                    );
+
                     $this->arguments['storyHTMLFile'] = $option[1];
                 }
                 break;
 
                 case '--story-text': {
+                    $this->showMessage(
+                      'The --story-text functionality is deprecated and ' .
+                      'will be removed in the future.',
+                      FALSE
+                    );
+
                     $this->arguments['storyTextFile'] = $option[1];
                 }
                 break;
@@ -629,8 +474,6 @@ class PHPUnit_TextUI_Command
                 break;
 
                 case '--testdox': {
-                    require_once 'PHPUnit/Util/TestDox/ResultPrinter/Text.php';
-
                     $this->arguments['printer'] = new PHPUnit_Util_TestDox_ResultPrinter_Text;
                 }
                 break;
@@ -676,6 +519,11 @@ class PHPUnit_TextUI_Command
                 }
                 break;
 
+                case '--strict': {
+                    $this->arguments['strict'] = TRUE;
+                }
+                break;
+
                 default: {
                     $optionName = str_replace('--', '', $option[0]);
 
@@ -730,20 +578,39 @@ class PHPUnit_TextUI_Command
         }
 
         if (isset($this->arguments['bootstrap'])) {
-            PHPUnit_Util_Fileloader::load($this->arguments['bootstrap']);
+            $this->handleBootstrap($this->arguments['bootstrap'], $this->arguments['syntaxCheck']);
         }
 
         if ($this->arguments['loader'] !== NULL) {
             $this->arguments['loader'] = $this->handleLoader($this->arguments['loader']);
         }
 
-        if (!isset($this->arguments['configuration']) && $this->arguments['useDefaultConfiguration']) {
-            if (file_exists('phpunit.xml')) {
-                $this->arguments['configuration'] = realpath('phpunit.xml');
+        if (isset($this->arguments['configuration']) &&
+            is_dir($this->arguments['configuration'])) {
+            $configurationFile = $this->arguments['configuration'] .
+                                 '/phpunit.xml';
+
+            if (file_exists($configurationFile)) {
+                $this->arguments['configuration'] = realpath(
+                  $configurationFile
+                );
             }
 
-            else if (file_exists('phpunit.xml.dist')) {
-                $this->arguments['configuration'] = realpath('phpunit.xml.dist');
+            else if (file_exists($configurationFile . '.dist')) {
+                $this->arguments['configuration'] = realpath(
+                  $configurationFile . '.dist'
+                );
+            }
+        }
+
+        else if (!isset($this->arguments['configuration']) &&
+                 $this->arguments['useDefaultConfiguration']) {
+            if (file_exists('phpunit.xml')) {
+                $this->arguments['configuration'] = realpath('phpunit.xml');
+            } else if (file_exists('phpunit.xml.dist')) {
+                $this->arguments['configuration'] = realpath(
+                  'phpunit.xml.dist'
+                );
             }
         }
 
@@ -776,14 +643,13 @@ class PHPUnit_TextUI_Command
                 $phpunitConfiguration = $configuration->getPHPUnitConfiguration();
 
                 if (isset($phpunitConfiguration['bootstrap'])) {
-                    PHPUnit_Util_Fileloader::load($phpunitConfiguration['bootstrap']);
+                    $this->handleBootstrap($phpunitConfiguration['bootstrap'], $this->arguments['syntaxCheck']);
                 }
             }
 
             $browsers = $configuration->getSeleniumBrowserConfiguration();
 
             if (!empty($browsers)) {
-                require_once 'PHPUnit/Extensions/SeleniumTestCase.php';
                 PHPUnit_Extensions_SeleniumTestCase::$browsers = $browsers;
             }
 
@@ -799,8 +665,6 @@ class PHPUnit_TextUI_Command
         }
 
         if (isset($this->arguments['test']) && is_string($this->arguments['test']) && substr($this->arguments['test'], -5, 5) == '.phpt') {
-            require_once 'PHPUnit/Extensions/PhptTestCase.php';
-
             $test = new PHPUnit_Extensions_PhptTestCase($this->arguments['test']);
 
             $this->arguments['test'] = new PHPUnit_Framework_TestSuite;
@@ -822,12 +686,8 @@ class PHPUnit_TextUI_Command
                 PHPUnit_TextUI_TestRunner::printVersionString();
 
                 if ($skeletonClass) {
-                    require_once 'PHPUnit/Util/Skeleton/Class.php';
-
                     $class = 'PHPUnit_Util_Skeleton_Class';
                 } else {
-                    require_once 'PHPUnit/Util/Skeleton/Test.php';
-
                     $class = 'PHPUnit_Util_Skeleton_Test';
                 }
 
@@ -910,6 +770,23 @@ class PHPUnit_TextUI_Command
         return $loader;
     }
 
+    /**
+     * Loads a bootstrap file.
+     *
+     * @param  string  $filename
+     * @param  boolean $syntaxCheck
+     */
+    protected function handleBootstrap($filename, $syntaxCheck = FALSE)
+    {
+        try {
+            PHPUnit_Util_Fileloader::checkAndLoad($filename, $syntaxCheck);
+        }
+
+        catch (RuntimeException $e) {
+            PHPUnit_TextUI_TestRunner::showError($e->getMessage());
+        }
+    }
+
     /**
      * Shows a message.
      *
@@ -941,14 +818,11 @@ Usage: phpunit [switches] UnitTest [UnitTest.php]
 
   --log-junit <file>       Log test execution in JUnit XML format to file.
   --log-tap <file>         Log test execution in TAP format to file.
+  --log-dbus               Log test execution to DBUS.
   --log-json <file>        Log test execution in JSON format.
 
   --coverage-html <dir>    Generate code coverage report in HTML format.
   --coverage-clover <file> Write code coverage data in Clover XML format.
-  --coverage-source <dir>  Write code coverage / source data in XML format.
-
-  --story-html <file>      Write Story/BDD results in HTML format to file.
-  --story-text <file>      Write Story/BDD results in Text format to file.
 
   --testdox-html <file>    Write agile documentation in HTML format to file.
   --testdox-text <file>    Write agile documentation in Text format to file.
@@ -961,13 +835,16 @@ Usage: phpunit [switches] UnitTest [UnitTest.php]
   --loader <loader>        TestSuiteLoader implementation to use.
   --repeat <times>         Runs the test(s) repeatedly.
 
-  --story                  Report test execution progress in Story/BDD format.
   --tap                    Report test execution progress in TAP format.
   --testdox                Report test execution progress in TestDox format.
 
   --colors                 Use colors in output.
   --stderr                 Write to STDERR instead of STDOUT.
+  --stop-on-error          Stop execution upon first error.
   --stop-on-failure        Stop execution upon first error or failure.
+  --stop-on-skipped        Stop execution upon first skipped test.
+  --stop-on-incomplete     Stop execution upon first incomplete test.
+  --strict                 Mark a test as incomplete if no assertions are made.
   --verbose                Output more verbose information.
   --wait                   Waits for a keystroke after each test.
 
@@ -998,4 +875,3 @@ EOT;
     {
     }
 }
-?>
\ No newline at end of file
