@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2010, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2010, Sebastian Bergmann <sebastian@phpunit.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,10 +34,10 @@
  * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- * @category   Testing
  * @package    PHPUnit
- * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @subpackage Util
+ * @author     Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.1.0
@@ -47,20 +47,15 @@ if (!defined('T_NAMESPACE')) {
     define('T_NAMESPACE', 377);
 }
 
-require_once 'PHPUnit/Util/Filter.php';
-require_once 'PHPUnit/Util/InvalidArgumentHelper.php';
-
-PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
-
 /**
  * Class helpers.
  *
- * @category   Testing
  * @package    PHPUnit
- * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @subpackage Util
+ * @author     Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.4.14
+ * @version    Release: 3.5.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.1.0
  */
@@ -90,34 +85,6 @@ class PHPUnit_Util_Class
         );
     }
 
-    /**
-     * Stops the collection of loaded classes and
-     * returns the names of the files that declare the loaded classes.
-     *
-     * @return array
-     */
-    public static function collectEndAsFiles()
-    {
-        $result = self::collectEnd();
-        $count  = count($result);
-
-        for ($i = 0; $i < $count; $i++) {
-            $class = new ReflectionClass($result[$i]);
-
-            if ($class->isUserDefined()) {
-                $file = $class->getFileName();
-
-                if (file_exists($file)) {
-                    $result[$i] = $file;
-                } else {
-                    unset($result[$i]);
-                }
-            }
-        }
-
-        return $result;
-    }
-
     /**
      * Returns the class hierarchy for a given class.
      *
@@ -164,10 +131,11 @@ class PHPUnit_Util_Class
      * Returns the parameters of a function or method.
      *
      * @param  ReflectionFunction|ReflectionMethod $method
+     * @param  boolean                             $forCall
      * @return string
      * @since  Method available since Release 3.2.0
      */
-    public static function getMethodParameters($method)
+    public static function getMethodParameters($method, $forCall = FALSE)
     {
         $parameters = array();
 
@@ -178,35 +146,36 @@ class PHPUnit_Util_Class
                 $name .= 'arg' . $i;
             }
 
+            $default  = '';
             $typeHint = '';
 
-            if ($parameter->isArray()) {
-                $typeHint = 'array ';
-            } else {
-                try {
-                    $class = $parameter->getClass();
+            if (!$forCall) {
+                if ($parameter->isArray()) {
+                    $typeHint = 'array ';
+                } else {
+                    try {
+                        $class = $parameter->getClass();
+                    }
+
+                    catch (ReflectionException $e) {
+                        $class = FALSE;
+                    }
+
+                    if ($class) {
+                        $typeHint = $class->getName() . ' ';
+                    }
                 }
 
-                catch (ReflectionException $e) {
-                    $class = FALSE;
+                if ($parameter->isDefaultValueAvailable()) {
+                    $value   = $parameter->getDefaultValue();
+                    $default = ' = ' . var_export($value, TRUE);
                 }
 
-                if ($class) {
-                    $typeHint = $class->getName() . ' ';
+                else if ($parameter->isOptional()) {
+                    $default = ' = null';
                 }
             }
 
-            $default = '';
-
-            if ($parameter->isDefaultValueAvailable()) {
-                $value   = $parameter->getDefaultValue();
-                $default = ' = ' . var_export($value, TRUE);
-            }
-
-            else if ($parameter->isOptional()) {
-                $default = ' = null';
-            }
-
             $ref = '';
 
             if ($parameter->isPassedByReference()) {
@@ -219,39 +188,6 @@ class PHPUnit_Util_Class
         return join(', ', $parameters);
     }
 
-    /**
-     * Returns the sourcecode of a user-defined class.
-     *
-     * @param  string  $className
-     * @param  string  $methodName
-     * @return mixed
-     */
-    public static function getMethodSource($className, $methodName)
-    {
-        if ($className != 'global') {
-            $function = new ReflectionMethod($className, $methodName);
-        } else {
-            $function = new ReflectionFunction($methodName);
-        }
-
-        $filename = $function->getFileName();
-
-        if (file_exists($filename)) {
-            $file   = file($filename);
-            $result = '';
-            $start  = $function->getStartLine() - 1;
-            $end    = $function->getEndLine() - 1;
-
-            for ($line = $start; $line <= $end; $line++) {
-                $result .= $file[$line];
-            }
-
-            return $result;
-        } else {
-            return FALSE;
-        }
-    }
-
     /**
      * Returns the package information of a user-defined class.
      *
@@ -327,22 +263,8 @@ class PHPUnit_Util_Class
         while ($class) {
             $attributes = $class->getStaticProperties();
 
-            $key = $attributeName;
-
-            if (isset($attributes[$key])) {
-                return $attributes[$key];
-            }
-
-            $key = "\0*\0" . $attributeName;
-
-            if (isset($attributes[$key])) {
-                return $attributes[$key];
-            }
-
-            $key = "\0" . $class->getName() . "\0" . $attributeName;
-
-            if (isset($attributes[$key])) {
-                return $attributes[$key];
+            if (array_key_exists($attributeName, $attributes)) {
+                return $attributes[$attributeName];
             }
 
             $class = $class->getParentClass();
@@ -386,19 +308,6 @@ class PHPUnit_Util_Class
         }
 
         catch (ReflectionException $e) {
-            // Workaround for http://bugs.php.net/46064
-            if (version_compare(PHP_VERSION, '5.2.7', '<')) {
-                $reflector  = new ReflectionObject($object);
-                $attributes = $reflector->getProperties();
-
-                foreach ($attributes as $_attribute) {
-                    if ($_attribute->getName() == $attributeName) {
-                        $attribute = $_attribute;
-                        break;
-                    }
-                }
-            }
-
             $reflector = new ReflectionObject($object);
 
             while ($reflector = $reflector->getParentClass()) {
@@ -492,4 +401,3 @@ class PHPUnit_Util_Class
         return $result;
     }
 }
-?>
\ No newline at end of file
