@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2010, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2010, Sebastian Bergmann <sebastian@phpunit.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,31 +34,26 @@
  * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- * @category   Testing
  * @package    PHPUnit
- * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @subpackage Util_Skeleton
+ * @author     Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.3.0
  */
 
-require_once 'PHPUnit/Util/Filesystem.php';
-require_once 'PHPUnit/Util/Filter.php';
-require_once 'PHPUnit/Util/Skeleton.php';
-require_once 'PHPUnit/Util/Template.php';
-
-PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
+require_once 'Text/Template.php';
 
 /**
  * Generator for test class skeletons from classes.
  *
- * @category   Testing
  * @package    PHPUnit
- * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @subpackage Util_Skeleton
+ * @author     Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.4.14
+ * @version    Release: 3.5.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.3.0
  */
@@ -267,7 +262,7 @@ class PHPUnit_Util_Skeleton_Test extends PHPUnit_Util_Skeleton
                                 $template .= 'Static';
                             }
 
-                            $methodTemplate = new PHPUnit_Util_Template(
+                            $methodTemplate = new Text_Template(
                               sprintf(
                                 '%s%sTemplate%s%s.tpl',
 
@@ -311,7 +306,7 @@ class PHPUnit_Util_Skeleton_Test extends PHPUnit_Util_Skeleton
                 }
 
                 if (!$assertAnnotationFound) {
-                    $methodTemplate = new PHPUnit_Util_Template(
+                    $methodTemplate = new Text_Template(
                       sprintf(
                         '%s%sTemplate%sIncompleteTestMethod.tpl',
 
@@ -332,7 +327,7 @@ class PHPUnit_Util_Skeleton_Test extends PHPUnit_Util_Skeleton
             }
         }
 
-        $classTemplate = new PHPUnit_Util_Template(
+        $classTemplate = new Text_Template(
           sprintf(
             '%s%sTemplate%sTestClass.tpl',
 
@@ -382,4 +377,3 @@ class PHPUnit_Util_Skeleton_Test extends PHPUnit_Util_Skeleton
         }
     }
 }
-?>
\ No newline at end of file
